@@ -1,14 +1,16 @@
 """Top-level package for PyGeoUtils."""
+from importlib.metadata import PackageNotFoundError, version
+
 from ._utils import transform2tuple
 from .exceptions import (
-    EmptyResponse,
-    InvalidInputRange,
-    InvalidInputType,
-    InvalidInputValue,
-    MissingAttribute,
-    MissingColumns,
-    MissingCRS,
-    UnprojectedCRS,
+    EmptyResponseError,
+    InputRangeError,
+    InputTypeError,
+    InputValueError,
+    MissingAttributeError,
+    MissingColumnError,
+    MissingCRSError,
+    UnprojectedCRSError,
 )
 from .print_versions import show_versions
 from .pygeoutils import (
@@ -28,13 +30,9 @@ from .pygeoutils import (
 )
 
 try:
-    import importlib.metadata
-except ImportError:
-    import importlib_metadata
-
-    __version__ = importlib_metadata.version("pygeoutils")
-else:
-    __version__ = importlib.metadata.version("pygeoutils")
+    __version__ = version("pygeoutils")
+except PackageNotFoundError:
+    __version__ = "999"
 
 __all__ = [
     "arcgis2geojson",
@@ -51,13 +49,13 @@ __all__ = [
     "xarray_geomask",
     "Coordinates",
     "GeoBSpline",
-    "InvalidInputType",
-    "InvalidInputValue",
-    "InvalidInputRange",
-    "MissingAttribute",
-    "MissingColumns",
-    "MissingCRS",
-    "UnprojectedCRS",
-    "EmptyResponse",
+    "InputTypeError",
+    "InputValueError",
+    "InputRangeError",
+    "MissingAttributeError",
+    "MissingColumnError",
+    "MissingCRSError",
+    "UnprojectedCRSError",
+    "EmptyResponseError",
     "show_versions",
 ]
